#!/usr/local/bin/ruby23 --disable-gems

$LOAD_PATH.unshift('/usr/local/share/gitsh/ruby/lib')

require '/usr/local/share/gitsh/vendor/gems/setup.rb'
require 'gitsh/cli'

begin
  Gitsh::CLI.new.run
rescue => e
  $stderr.puts "gitsh: Error: #{e.message}"
  exit 1
end
